==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/zh_CN.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "动态",
    "Error loading activities" : "加载动态出错",
    "No activities" : "暂无动态",
    "Load more activities" : "加载更多动态",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "流中会显示诸如添加、更改和分享之类的事件",
    "There are no events for this filter" : "没有符合当前筛选条件的事件。",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Activity" : "动态",
    "Personal activity feed for %s" : "%s 的个人动态 Feed",
    "Your feed URL is invalid" : "您输入的Feed链接无效",
    "Your settings have been updated." : "您的设置已更新。",
    "Mail" : "邮件",
    "Stream" : "流",
    "All activities" : "所有动态",
    "By others" : "其他来源",
    "By you" : "本地来源",
    "\"remote user\"" : "远程用户",
    "Activity notification" : "动态通知",
    ", " : "，",
    "%s and %s" : "%s 和 %s",
    "Hello %s," : "%s 你好，",
    "You are receiving this email because the following things happened at %s" : "你收到此邮件是因为在 %s 发生了以下事件:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 以及其他 %n 项"],
    "Notify about your own actions via email" : "通过邮件通知您自己的动态",
    "You need to set up your email address before you can receive notification emails." : "要接收通知邮件，需要先设置您的电子邮件地址。",
    "Send emails:" : "发送邮件：",
    "Hourly" : "每小时",
    "Daily" : "每天",
    "Weekly" : "每周",
    "Activity feed" : "动态 Feed",
    "Enable RSS feed" : "启用 RSS 源",
    "No activity yet" : "暂无动态",
    "No more events to load" : "已无更多事件",
    "Files" : "文件"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/zh_CN.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "动态",
    "An error occurred while loading activities" : "加载动态时出错。",
    "No activity yet" : "暂无动态",
    "Load more activities" : "加载更多动态",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "{name} (invisible)" : "{name} (不可见)",
    "{name} (restricted)" : "{name} (受限的)",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "流中会显示诸如添加、更改和分享之类的事件",
    "There are no events for this filter" : "没有符合当前筛选条件的事件。",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Personal activity feed for %s" : "%s 的个人动态 Feed",
    "Your feed URL is invalid" : "您输入的Feed链接无效",
    "Your settings have been updated." : "您的设置已更新。",
    "Settings have been updated." : "设置已更新。",
    "Mail" : "邮件",
    "Stream" : "流",
    "All activities" : "所有动态",
    "By others" : "其他来源",
    "By you" : "本地来源",
    "\"remote user\"" : "远程用户",
    "Hello %s" : "你好%s",
    "Hello %s," : "%s 您好，",
    "There was some activity at %s" : "在 %s 里有一些动态",
    "_and %n more _::_and %n more _" : ["和%n等"],
    "Activity notification" : "动态通知",
    ", " : "，",
    "%s and %s" : "%s 和 %s",
    "Activity" : "动态",
    "Activity feed" : "动态 Feed",
    "Configure the default activity settings for new users." : "为新用户设置默认的活动配置",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "选择哪些活动你想收到提示邮件，这将显示在活动应用流里",
    "List your own actions in the stream" : "在流里面列出您自己的行为",
    "Notify about your own actions via email" : "通过邮件通知您自己的动态",
    "You need to set up your email address before you can receive notification emails." : "要接收通知邮件，需要先设置您的电子邮件地址。",
    "Send emails:" : "发送邮件：",
    "Hourly" : "每小时",
    "Daily" : "每天",
    "Weekly" : "每周",
    "Settings" : "设置",
    "Enable RSS feed" : "启用 RSS 源",
    "No more events to load" : "已无更多事件",
    "Files" : "文件",
    "Error loading activities" : "加载动态时出错",
    "No activities" : "暂无动态",
    "You are receiving this email because the following things happened at %s" : "你收到此邮件是因为在 %s 发生了以下事件:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 以及其他 %n 项"]
},
"nplurals=1; plural=0;");
